Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Driver ¶
type Driver interface {
// Purchase sends a purchase request to the driver's gateway.
Purchase(invoice *invoice.Invoice) (string, error)
// PayURL returns the url to redirect the user to for payment.
PayURL(invoice *invoice.Invoice) string
// GetDriverName returns the name of the driver.
GetDriverName() string
// Verify checks the payment status of the invoice.
Verify(vReq interface{}) (*receipt.Receipt, error)
// PayMethod returns the payment request method.
PayMethod() string
// SetClient sets the http client.
SetClient(client httpClient.Client)
// RenderRedirectForm renders the html form for redirect to payment page.
RenderRedirectForm(invoice *invoice.Invoice) (string, error)
}
Driver is the interface that must be implemented by all drivers.
Click to show internal directories.
Click to hide internal directories.